"""Country names to ISO3166_alpha2 codes mapping

Roughly generated by the following bash script on GNU/Linux:

    while read cc name; do
        [ ! "$cc" ] &&
            continue
        out=$(isoquery $cc | cut -f3 --complement);
        [ ! "$out" ] &&
            out="$cc"
        [ "$(echo $out | cut -f3)" = "$name" ] &&
            name=''
        echo -e "$out\t$name"    |
            sed -r 's/\s+$//'    |
            sed -r "s/\t/': ['/" |
            sed -r "s/\t/', '/g" |
            sed -r "s/^/'/"      |
            sed -r 's/$/'"'"',],/'
    done < input/cc.list  # cc.list from jVectorMap; format: lines start with ISO3166_alpha2_code else copied as is

Certain details updated by hand.
"""

CC_EUROPE = {
    '_0': ['Kosovo', 'Kosovo, Republic of'],
    '-99': ['N. Cyprus', 'North Cyprus'],
    'AD': ['AND', 'Andorra'],
    'AL': ['ALB', 'Albania'],
    'AT': ['AUT', 'Austria'],
    'AX': ['ALA', 'Åland Islands', 'Aland'],
    'BA': ['BIH', 'Bosnia and Herzegovina', 'Bosnia and Herz.'],
    'BE': ['BEL', 'Belgium'],
    'BG': ['BGR', 'Bulgaria'],
    'BY': ['BLR', 'Belarus'],
    'CH': ['CHE', 'Switzerland'],
    'CY': ['CYP', 'Cyprus'],
    'CZ': ['CZE', 'Czech Republic', 'Czech Rep.'],
    'DE': ['DEU', 'Germany'],
    'DK': ['DNK', 'Denmark'],
    'DZ': ['DZA', 'Algeria'],
    'EE': ['EST', 'Estonia'],
    'EG': ['EGY', 'Egypt'],
    'ES': ['ESP', 'Spain'],
    'FI': ['FIN', 'Finland'],
    'FO': ['FRO', 'Faroe Islands', 'Faeroe Is.'],
    'FR': ['FRA', 'France'],
    'GB': ['GBR', 'United Kingdom'],
    'GE': ['GEO', 'Georgia'],
    'GG': ['GGY', 'Guernsey'],
    'GR': ['GRC', 'Greece'],
    'HR': ['HRV', 'Croatia'],
    'HU': ['HUN', 'Hungary'],
    'IE': ['IRL', 'Ireland'],
    'IL': ['ISR', 'Israel'],
    'IM': ['IMN', 'Isle of Man'],
    'IQ': ['IRQ', 'Iraq'],
    'IS': ['ISL', 'Iceland'],
    'IT': ['ITA', 'Italy'],
    'JE': ['JEY', 'Jersey'],
    'JO': ['JOR', 'Jordan'],
    'LB': ['LBN', 'Lebanon'],
    'LI': ['LIE', 'Liechtenstein'],
    'LT': ['LTU', 'Lithuania'],
    'LU': ['LUX', 'Luxembourg'],
    'LV': ['LVA', 'Latvia'],
    'LY': ['LBY', 'Libya'],
    'MA': ['MAR', 'Morocco'],
    'MD': ['MDA', 'Moldova, Republic of', 'Moldova'],
    'ME': ['MNE', 'Montenegro'],
    'MK': ['MKD', 'Macedonia, Republic of', 'Macedonia'],
    'MT': ['MLT', 'Malta'],
    'NL': ['NLD', 'Netherlands'],
    'NO': ['NOR', 'Norway'],
    'PL': ['POL', 'Poland'],
    'PS': ['PSE', 'Palestine, State of', 'Palestine'],
    'PT': ['PRT', 'Portugal'],
    'RO': ['ROU', 'Romania'],
    'RS': ['SRB', 'Serbia'],
    'RU': ['RUS', 'Russian Federation', 'Russia'],
    'SA': ['SAU', 'Saudi Arabia'],
    'SE': ['SWE', 'Sweden'],
    'SI': ['SVN', 'Slovenia'],
    'SK': ['SVK', 'Slovakia'],
    'SM': ['SMR', 'San Marino'],
    'SY': ['SYR', 'Syrian Arab Republic', 'Syria'],
    'TN': ['TUN', 'Tunisia'],
    'TR': ['TUR', 'Turkey'],
    'UA': ['UKR', 'Ukraine'],
}


CC_WORLD = {
    # Does NOT include CC_EUROPE
    '_1': ['Somaliland',],
    'AE': ['ARE', 'United Arab Emirates'],
    'AF': ['AFG', 'Afghanistan'],
    'AM': ['ARM', 'Armenia'],
    'AO': ['AGO', 'Angola'],
    'AR': ['ARG', 'Argentina'],
    'AU': ['AUS', 'Australia'],
    'AZ': ['AZE', 'Azerbaijan'],
    'BD': ['BGD', 'Bangladesh'],
    'BF': ['BFA', 'Burkina Faso'],
    'BI': ['BDI', 'Burundi'],
    'BJ': ['BEN', 'Benin'],
    'BN': ['BRN', 'Brunei Darussalam', 'Brunei'],
    'BO': ['BOL', 'Bolivia, Plurinational State of', 'Bolivia'],
    'BR': ['BRA', 'Brazil'],
    'BS': ['BHS', 'Bahamas'],
    'BT': ['BTN', 'Bhutan'],
    'BW': ['BWA', 'Botswana'],
    'BZ': ['BLZ', 'Belize'],
    'CA': ['CAN', 'Canada'],
    'CD': ['COD', 'Congo, The Democratic Republic of the', 'Dem. Rep. Congo'],
    'CF': ['CAF', 'Central African Republic', 'Central African Rep.'],
    'CG': ['COG', 'Congo'],
    'CI': ['CIV', "Côte d'Ivoire"],
    'CL': ['CHL', 'Chile'],
    'CM': ['CMR', 'Cameroon'],
    'CN': ['CHN', 'China'],
    'CO': ['COL', 'Colombia'],
    'CR': ['CRI', 'Costa Rica'],
    'CU': ['CUB', 'Cuba'],
    'DJ': ['DJI', 'Djibouti'],
    'DO': ['DOM', 'Dominican Republic', 'Dominican Rep.'],
    'EC': ['ECU', 'Ecuador'],
    'EH': ['ESH', 'Western Sahara', 'W. Sahara'],
    'ER': ['ERI', 'Eritrea'],
    'ET': ['ETH', 'Ethiopia'],
    'FJ': ['FJI', 'Fiji'],
    'FK': ['FLK', 'Falkland Islands [Malvinas]', 'Falkland Is.'],
    'GA': ['GAB', 'Gabon'],
    'GH': ['GHA', 'Ghana'],
    'GL': ['GRL', 'Greenland'],
    'GM': ['GMB', 'Gambia'],
    'GN': ['GIN', 'Guinea'],
    'GQ': ['GNQ', 'Equatorial Guinea', 'Eq. Guinea'],
    'GT': ['GTM', 'Guatemala'],
    'GW': ['GNB', 'Guinea-Bissau'],
    'GY': ['GUY', 'Guyana'],
    'HN': ['HND', 'Honduras'],
    'HT': ['HTI', 'Haiti'],
    'ID': ['IDN', 'Indonesia'],
    'IN': ['IND', 'India'],
    'IR': ['IRN', 'Iran, Islamic Republic of', 'Iran'],
    'JM': ['JAM', 'Jamaica'],
    'JP': ['JPN', 'Japan'],
    'KE': ['KEN', 'Kenya'],
    'KG': ['KGZ', 'Kyrgyzstan'],
    'KH': ['KHM', 'Cambodia'],
    'KP': ['PRK', "Korea, Democratic People's Republic of", 'Dem. Rep. Korea', 'North Korea'],
    'KR': ['KOR', 'Korea, Republic of', 'Korea', 'South Korea'],
    'KW': ['KWT', 'Kuwait'],
    'KZ': ['KAZ', 'Kazakhstan'],
    'LA': ['LAO', "Lao People's Democratic Republic", 'Lao PDR'],
    'LK': ['LKA', 'Sri Lanka'],
    'LR': ['LBR', 'Liberia'],
    'LS': ['LSO', 'Lesotho'],
    'MG': ['MDG', 'Madagascar'],
    'ML': ['MLI', 'Mali'],
    'MM': ['MMR', 'Myanmar'],
    'MN': ['MNG', 'Mongolia'],
    'MR': ['MRT', 'Mauritania'],
    'MW': ['MWI', 'Malawi'],
    'MX': ['MEX', 'Mexico'],
    'MY': ['MYS', 'Malaysia'],
    'MZ': ['MOZ', 'Mozambique'],
    'NA': ['NAM', 'Namibia'],
    'NC': ['NCL', 'New Caledonia'],
    'NE': ['NER', 'Niger'],
    'NG': ['NGA', 'Nigeria'],
    'NI': ['NIC', 'Nicaragua'],
    'NP': ['NPL', 'Nepal'],
    'NZ': ['NZL', 'New Zealand'],
    'OM': ['OMN', 'Oman'],
    'PA': ['PAN', 'Panama'],
    'PE': ['PER', 'Peru'],
    'PG': ['PNG', 'Papua New Guinea'],
    'PH': ['PHL', 'Philippines'],
    'PK': ['PAK', 'Pakistan'],
    'PR': ['PRI', 'Puerto Rico'],
    'PY': ['PRY', 'Paraguay'],
    'QA': ['QAT', 'Qatar'],
    'RW': ['RWA', 'Rwanda'],
    'SB': ['SLB', 'Solomon Islands', 'Solomon Is.'],
    'SD': ['SDN', 'Sudan'],
    'SL': ['SLE', 'Sierra Leone'],
    'SN': ['SEN', 'Senegal'],
    'SO': ['SOM', 'Somalia'],
    'SR': ['SUR', 'Suriname'],
    'SS': ['SSD', 'South Sudan', 'S. Sudan'],
    'SV': ['SLV', 'El Salvador'],
    'SZ': ['SWZ', 'Swaziland'],
    'TD': ['TCD', 'Chad'],
    'TF': ['ATF', 'French Southern Territories', 'Fr. S. Antarctic Lands'],
    'TG': ['TGO', 'Togo'],
    'TH': ['THA', 'Thailand'],
    'TJ': ['TJK', 'Tajikistan'],
    'TL': ['TLS', 'Timor-Leste'],
    'TM': ['TKM', 'Turkmenistan'],
    'TT': ['TTO', 'Trinidad and Tobago'],
    'TW': ['TWN', 'Taiwan, Province of China', 'Taiwan'],
    'TZ': ['TZA', 'Tanzania, United Republic of', 'Tanzania'],
    'UG': ['UGA', 'Uganda'],
    'US': ['USA', 'United States', 'United States of America'],
    'UY': ['URY', 'Uruguay'],
    'UZ': ['UZB', 'Uzbekistan'],
    'VE': ['VEN', 'Venezuela, Bolivarian Republic of', 'Venezuela'],
    'VN': ['VNM', 'Viet Nam', 'Vietnam'],
    'VU': ['VUT', 'Vanuatu'],
    'YE': ['YEM', 'Yemen'],
    'ZA': ['ZAF', 'South Africa'],
    'ZM': ['ZMB', 'Zambia'],
    'ZW': ['ZWE', 'Zimbabwe'],
}
CC_WORLD.update(CC_EUROPE)


CC_USA = {
    'US-AK': ['AK', 'Alaska'],
    'US-AL': ['AL', 'Alabama'],
    'US-AR': ['AR', 'Arkansas'],
    'US-AZ': ['AZ', 'Arizona'],
    'US-CA': ['CA', 'California'],
    'US-CO': ['CO', 'Colorado'],
    'US-CT': ['CT', 'Connecticut'],
    'US-DC': ['DC', 'District of Columbia'],
    'US-DE': ['DE', 'Delaware'],
    'US-FL': ['FL', 'Florida'],
    'US-GA': ['GA', 'Georgia'],
    'US-HI': ['HI', 'Hawaii'],
    'US-IA': ['IA', 'Iowa'],
    'US-ID': ['ID', 'Idaho'],
    'US-IL': ['IL', 'Illinois'],
    'US-IN': ['IN', 'Indiana'],
    'US-KS': ['KS', 'Kansas'],
    'US-KY': ['KY', 'Kentucky'],
    'US-LA': ['LA', 'Louisiana'],
    'US-MA': ['MA', 'Massachusetts'],
    'US-MD': ['MD', 'Maryland'],
    'US-ME': ['ME', 'Maine'],
    'US-MI': ['MI', 'Michigan'],
    'US-MN': ['MN', 'Minnesota'],
    'US-MO': ['MO', 'Missouri'],
    'US-MS': ['MS', 'Mississippi'],
    'US-MT': ['MT', 'Montana'],
    'US-NC': ['NC', 'North Carolina'],
    'US-ND': ['ND', 'North Dakota'],
    'US-NE': ['NE', 'Nebraska'],
    'US-NH': ['NH', 'New Hampshire'],
    'US-NJ': ['NJ', 'New Jersey'],
    'US-NM': ['NM', 'New Mexico'],
    'US-NV': ['NV', 'Nevada'],
    'US-NY': ['NY', 'New York'],
    'US-OH': ['OH', 'Ohio'],
    'US-OK': ['OK', 'Oklahoma'],
    'US-OR': ['OR', 'Oregon'],
    'US-PA': ['PA', 'Pennsylvania'],
    'US-RI': ['RI', 'Rhode Island'],
    'US-SC': ['SC', 'South Carolina'],
    'US-SD': ['SD', 'South Dakota'],
    'US-TN': ['TN', 'Tennessee'],
    'US-TX': ['TX', 'Texas'],
    'US-UT': ['UT', 'Utah'],
    'US-VA': ['VA', 'Virginia'],
    'US-VT': ['VT', 'Vermont'],
    'US-WA': ['WA', 'Washington'],
    'US-WI': ['WI', 'Wisconsin'],
    'US-WV': ['WV', 'West Virginia'],
    'US-WY': ['WY', 'Wyoming'],
}


def _invert_mapping(dict):
    return {v:k for k in dict for v in dict[k]}


INV_CC_EUROPE = _invert_mapping(CC_EUROPE)
INV_CC_WORLD = _invert_mapping(CC_WORLD)
INV_CC_USA = _invert_mapping(CC_USA)

SET_CC_EUROPE = set(INV_CC_EUROPE.keys()) | set(INV_CC_EUROPE.values())
SET_CC_USA = set(INV_CC_USA.keys()) | set(INV_CC_USA.values())
